@@ -16,13 +16,13 @@ use experimental 'signatures';
 use Feature::Compat::Try;
 use Future::AsyncAwait;
 
-package Sys::Async::Virt::Callback v0.0.10;
+package Sys::Async::Virt::Callback v0.0.11;
 
 use Carp qw(croak);
 use Future::Queue;
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.0.10;
+use Protocol::Sys::Virt::Remote::XDR v0.0.11;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
 sub new($class, %args) {
@@ -90,7 +90,7 @@ Sys::Async::Virt::Callback - Client side proxy to remote LibVirt event source
 
 =head1 VERSION
 
-v0.0.10
+v0.0.11
 
 =head1 SYNOPSIS
 
@@ -98,7 +98,7 @@ v0.0.10
      $client->DOMAIN_EVENT_ID_LIFECYCLE );
 
   while (my $event = await $cb->next_event) {
-     my $dom = $event->{msg}->{dom};
+     my $dom = $event->{dom};
 
      # process the event
      if ($event->{event} == $dom->EVENT_STOPPED) {
